@@ -1249,7 +1249,7 @@ static const SECTION union { const guint8 data[9920]; const double alignment; vo
   0x2f, 0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { gtr_codeview_resource_data.data, sizeof (gtr_codeview_resource_data.data) };
+static GStaticResource static_resource = { gtr_codeview_resource_data.data, sizeof (gtr_codeview_resource_data.data), NULL, NULL, NULL };
 extern GResource *gtr_codeview_get_resource (void);
 GResource *gtr_codeview_get_resource (void)
 {
@@ -1273,6 +1273,8 @@ GResource *gtr_codeview_get_resource (void)
 
 */
 
+#ifndef __GTK_DOC_IGNORE__
+
 #if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)
 
 #define G_HAS_CONSTRUCTORS 1
@@ -1346,6 +1348,7 @@ GResource *gtr_codeview_get_resource (void)
 
 #endif
 
+#endif /* __GTK_DOC_IGNORE__ */
 
 #ifdef G_HAS_CONSTRUCTORS
 
