@@ -1186,7 +1186,7 @@ static const SECTION union { const guint8 data[9412]; const double alignment; vo
   0x04, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { gtr_open_tran_resource_data.data, sizeof (gtr_open_tran_resource_data.data) };
+static GStaticResource static_resource = { gtr_open_tran_resource_data.data, sizeof (gtr_open_tran_resource_data.data), NULL, NULL, NULL };
 extern GResource *gtr_open_tran_get_resource (void);
 GResource *gtr_open_tran_get_resource (void)
 {
@@ -1210,6 +1210,8 @@ GResource *gtr_open_tran_get_resource (void)
 
 */
 
+#ifndef __GTK_DOC_IGNORE__
+
 #if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)
 
 #define G_HAS_CONSTRUCTORS 1
@@ -1283,6 +1285,7 @@ GResource *gtr_open_tran_get_resource (void)
 
 #endif
 
+#endif /* __GTK_DOC_IGNORE__ */
 
 #ifdef G_HAS_CONSTRUCTORS
 
