@@ -8,6 +8,11 @@
 
 G_BEGIN_DECLS
 
+/* Enumerations from "gtr-message-table.h" */
+
+#define GTR_TYPE_MESSAGE_TABLE_NAVIGATION	(gtr_message_table_navigation_get_type())
+GType gtr_message_table_navigation_get_type	(void) G_GNUC_CONST;
+
 /* Enumerations from "gtr-msg.h" */
 
 #define GTR_TYPE_MSG_STATUS	(gtr_msg_status_get_type())
